==> dependency-cruiser-8.0.2.tgz: package/src/report/error-html/index.js <==
/* eslint-disable security/detect-object-injection */
const Handlebars = require("handlebars/runtime");
const _get = require("lodash/get");
const {
  getFormattedAllowedRule,
  mergeCountIntoRule,
  formatSummaryForReport
} = require("./utl");

// eslint-disable-next-line import/no-unassigned-import
require("./error-html.template");

function aggregateViolations(pViolations, pRuleSetUsed) {
  const lViolationCounts = pViolations.reduce((pAll, pCurrentViolation) => {
    if (pAll[pCurrentViolation.rule.name]) {
      pAll[pCurrentViolation.rule.name] += 1;
    } else {
      pAll[pCurrentViolation.rule.name] = 1;
    }
    return pAll;
  }, {});

  return _get(pRuleSetUsed, "forbidden", [])
    .concat(getFormattedAllowedRule(pRuleSetUsed))
    .map(pRule => mergeCountIntoRule(pRule, lViolationCounts))
    .sort(
      (pFirst, pSecond) =>
        Math.sign(pSecond.count - pFirst.count) ||
        pFirst.name.localeCompare(pSecond.name)
    );
}

function report(pResults) {
  return Handlebars.templates["error-html.template.hbs"]({
    summary: {
      ...formatSummaryForReport(pResults.summary),
      agggregateViolations: aggregateViolations(
        pResults.summary.violations,
        pResults.summary.ruleSetUsed
      )
    }
  });
}

/**
 * Returns the results of a cruise in an 'incidence matrix'
 *
 * @param {ICruiseResult} pResults - the output of a dependency-cruise adhering to ../../schema/cruise-result.schema.json
 * @returns {IReporterOutput} - output: an html program showing the summary & the violations (if any)
 *                              exitCode: 0
 */
module.exports = pResults => ({
  output: report(pResults),
  exitCode: 0
});

==> dependency-cruiser-9.4.0.tgz: package/src/report/error-html/index.js <==
/* eslint-disable security/detect-object-injection */
const Handlebars = require("handlebars/runtime");
const _get = require("lodash/get");
const {
  getFormattedAllowedRule,
  mergeCountIntoRule,
  formatSummaryForReport,
} = require("./utl");

// eslint-disable-next-line import/no-unassigned-import
require("./error-html.template");

function aggregateViolations(pViolations, pRuleSetUsed) {
  const lViolationCounts = pViolations.reduce((pAll, pCurrentViolation) => {
    if (pAll[pCurrentViolation.rule.name]) {
      pAll[pCurrentViolation.rule.name] += 1;
    } else {
      pAll[pCurrentViolation.rule.name] = 1;
    }
    return pAll;
  }, {});

  return _get(pRuleSetUsed, "forbidden", [])
    .concat(getFormattedAllowedRule(pRuleSetUsed))
    .map((pRule) => mergeCountIntoRule(pRule, lViolationCounts))
    .sort(
      (pFirst, pSecond) =>
        Math.sign(pSecond.count - pFirst.count) ||
        pFirst.name.localeCompare(pSecond.name)
    );
}

function report(pResults) {
  return Handlebars.templates["error-html.template.hbs"]({
    summary: {
      ...formatSummaryForReport(pResults.summary),
      agggregateViolations: aggregateViolations(
        pResults.summary.violations,
        pResults.summary.ruleSetUsed
      ),
    },
  });
}

/**
 * Returns the results of a cruise in an 'incidence matrix'
 *
 * @param {ICruiseResult} pResults - the output of a dependency-cruise adhering to ../../schema/cruise-result.schema.json
 * @returns {IReporterOutput} - output: an html program showing the summary & the violations (if any)
 *                              exitCode: 0
 */
module.exports = (pResults) => ({
  output: report(pResults),
  exitCode: 0,
});
